# Utilities

Caterva2 comes with several command-line utilities for different tasks.

## Main Commands

The main utilities follow a new unified naming scheme:

- **cat2-client**: Query a server from terminal
- **cat2-agent**: Watch a directory and sync changes to a Caterva2 server
- **cat2-server**: Launch the server with fine-tuned behavior
- **cat2-admin**: Server administration commands (new)

```{toctree}
---
maxdepth: 2
---

cat2-client
cat2-agent
cat2-server
cat2-admin
```
